@@ -2,11 +2,11 @@ CREATE TABLE subscriber (
     id NUMBER(10) PRIMARY KEY,
     username VARCHAR2(64) DEFAULT '',
     domain VARCHAR2(64) DEFAULT '',
-    password VARCHAR2(25) DEFAULT '',
-    email_address VARCHAR2(64) DEFAULT '',
-    ha1 VARCHAR2(64) DEFAULT '',
-    ha1b VARCHAR2(64) DEFAULT '',
-    rpid VARCHAR2(64) DEFAULT NULL,
+    password VARCHAR2(64) DEFAULT '',
+    ha1 VARCHAR2(128) DEFAULT '',
+    ha1b VARCHAR2(128) DEFAULT '',
+    email_address VARCHAR2(128) DEFAULT NULL,
+    rpid VARCHAR2(128) DEFAULT NULL,
     CONSTRAINT subscriber_account_idx  UNIQUE (username, domain)
 );
 
@@ -20,5 +20,5 @@ BEGIN map2users('subscriber'); END;
 /
 CREATE INDEX subscriber_username_idx  ON subscriber (username);
 
-INSERT INTO version (table_name, table_version) values ('subscriber','6');
+INSERT INTO version (table_name, table_version) values ('subscriber','7');
 
