@@ -2,15 +2,15 @@ CREATE TABLE subscriber (
     id SERIAL PRIMARY KEY NOT NULL,
     username VARCHAR(64) DEFAULT '' NOT NULL,
     domain VARCHAR(64) DEFAULT '' NOT NULL,
-    password VARCHAR(25) DEFAULT '' NOT NULL,
-    email_address VARCHAR(64) DEFAULT '' NOT NULL,
-    ha1 VARCHAR(64) DEFAULT '' NOT NULL,
-    ha1b VARCHAR(64) DEFAULT '' NOT NULL,
-    rpid VARCHAR(64) DEFAULT NULL,
+    password VARCHAR(64) DEFAULT '' NOT NULL,
+    ha1 VARCHAR(128) DEFAULT '' NOT NULL,
+    ha1b VARCHAR(128) DEFAULT '' NOT NULL,
+    email_address VARCHAR(128) DEFAULT NULL,
+    rpid VARCHAR(128) DEFAULT NULL,
     CONSTRAINT subscriber_account_idx UNIQUE (username, domain)
 );
 
 CREATE INDEX subscriber_username_idx ON subscriber (username);
 
-INSERT INTO version (table_name, table_version) values ('subscriber','6');
+INSERT INTO version (table_name, table_version) values ('subscriber','7');
 
