@@ -1,4 +1,3 @@
-INSERT INTO version (table_name, table_version) values ('presentity','4');
 CREATE TABLE presentity (
     id SERIAL PRIMARY KEY NOT NULL,
     username VARCHAR(64) NOT NULL,
@@ -16,7 +15,8 @@ CREATE TABLE presentity (
 CREATE INDEX presentity_presentity_expires ON presentity (expires);
 CREATE INDEX presentity_account_idx ON presentity (username, domain, event);
 
-INSERT INTO version (table_name, table_version) values ('active_watchers','11');
+INSERT INTO version (table_name, table_version) values ('presentity','4');
+
 CREATE TABLE active_watchers (
     id SERIAL PRIMARY KEY NOT NULL,
     presentity_uri VARCHAR(128) NOT NULL,
@@ -35,7 +35,7 @@ CREATE TABLE active_watchers (
     record_route TEXT,
     expires INTEGER NOT NULL,
     status INTEGER DEFAULT 2 NOT NULL,
-    reason VARCHAR(64) NOT NULL,
+    reason VARCHAR(64),
     version INTEGER DEFAULT 0 NOT NULL,
     socket_info VARCHAR(64) NOT NULL,
     local_contact VARCHAR(128) NOT NULL,
@@ -43,6 +43,8 @@ CREATE TABLE active_watchers (
     from_domain VARCHAR(64) NOT NULL,
     updated INTEGER NOT NULL,
     updated_winfo INTEGER NOT NULL,
+    flags INTEGER DEFAULT 0 NOT NULL,
+    user_agent VARCHAR(255) DEFAULT '',
     CONSTRAINT active_watchers_active_watchers_idx UNIQUE (callid, to_tag, from_tag)
 );
 
@@ -51,7 +53,8 @@ CREATE INDEX active_watchers_active_watchers_pres ON active_watchers (presentity
 CREATE INDEX active_watchers_updated_idx ON active_watchers (updated);
 CREATE INDEX active_watchers_updated_winfo_idx ON active_watchers (updated_winfo, presentity_uri);
 
-INSERT INTO version (table_name, table_version) values ('watchers','3');
+INSERT INTO version (table_name, table_version) values ('active_watchers','12');
+
 CREATE TABLE watchers (
     id SERIAL PRIMARY KEY NOT NULL,
     presentity_uri VARCHAR(128) NOT NULL,
@@ -64,7 +67,8 @@ CREATE TABLE watchers (
     CONSTRAINT watchers_watcher_idx UNIQUE (presentity_uri, watcher_username, watcher_domain, event)
 );
 
-INSERT INTO version (table_name, table_version) values ('xcap','4');
+INSERT INTO version (table_name, table_version) values ('watchers','3');
+
 CREATE TABLE xcap (
     id SERIAL PRIMARY KEY NOT NULL,
     username VARCHAR(64) NOT NULL,
@@ -82,7 +86,8 @@ CREATE INDEX xcap_account_doc_type_idx ON xcap (username, domain, doc_type);
 CREATE INDEX xcap_account_doc_type_uri_idx ON xcap (username, domain, doc_type, doc_uri);
 CREATE INDEX xcap_account_doc_uri_idx ON xcap (username, domain, doc_uri);
 
-INSERT INTO version (table_name, table_version) values ('pua','7');
+INSERT INTO version (table_name, table_version) values ('xcap','4');
+
 CREATE TABLE pua (
     id SERIAL PRIMARY KEY NOT NULL,
     pres_uri VARCHAR(128) NOT NULL,
@@ -111,3 +116,5 @@ CREATE INDEX pua_dialog1_idx ON pua (pres_id, pres_uri);
 CREATE INDEX pua_dialog2_idx ON pua (call_id, from_tag);
 CREATE INDEX pua_record_idx ON pua (pres_id);
 
+INSERT INTO version (table_name, table_version) values ('pua','7');
+
